from __future__ import unicode_literals

from django.db import models
from django.forms import ModelForm

class Bibliography(models.Model):
    """
    Bibliography data table
    """
    SOURCES = (
        ('PM', 'PubMed article'),
        ('PT', 'Patent')
    )
    source = models.CharField('Bibliographic type', max_length=2, choices=SOURCES)
    id_source = models.CharField('Bibliographic ID', max_length=25)
    title = models.CharField('Title', max_length=300)
    journal_name = models.CharField('Journal name', max_length=50)
    authors_list = models.CharField('Authors list', max_length=500)
    biblio_year = models.PositiveSmallIntegerField('Year')
    cytotox = models.BooleanField('Cytotoxicity data')
    in_silico = models.BooleanField('in silico study performed')
    in_vitro = models.BooleanField('in vitro study performed')
    in_vivo = models.BooleanField('in vivo study performed')
    in_cellulo = models.BooleanField('in cellulo study performed')
    pharmacokinetic = models.BooleanField('pharmacokinetic study performed')
    xray = models.BooleanField('contains xray data')

    def get_absolute_url(self):
        return reverse('bibliography-detail', args=[str(self.id)])

    def save(self, *args, **kwargs):
        pubmed_info = get_pubmed_info(self.id_source)
        self.title = pubmed_info['title']
        self.journal_name = pubmed_info['journal_name']
        self.authors_list = pubmed_info['authors_list']
        self.biblio_year = pubmed_info['biblio_year']
        super(Bibliography, self).save(*args, **kwargs)

class BibliographyForm(ModelForm):
    class Meta:
        model = Bibliography
        fields = '__all__'

class Taxonomy(models.Model):
    taxonomy_id = models.DecimalField('NCBI TaxID', unique=True, max_digits=4, decimal_places=0)
    name = models.CharField('Organism name', max_length=200)

class MolecularFunction(models.Model):
    go_id = models.CharField('Gene Ontology ID', unique=True, max_length=10) # GO term id format: 'GO:0000000' 
    description = models.CharField('description', max_length=500)

class Protein(models.Model):
    uniprot_id = models.CharField('Uniprot ID', unique=True, max_length=10)
    recommended_name_long = models.CharField('Uniprot Recommended Name (long)', max_length=75)
    short_name = models.CharField('Short name', max_length=50)
    gene_name = models.CharField('Gene name', unique=True, max_length=30)
    entry_name = models.CharField('Entry name', max_length=30)
    organism = models.ForeignKey('Taxonomy')
    molecular_functions = models.ManyToManyField(MolecularFunction)

class Domain(models.Model):
    pfam_acc = models.CharField('Pfam Accession', max_length=10, unique=True) 
    pfam_id = models.CharField('Pfam Family Identifier', max_length=20) 
    pfam_description = models.CharField('Pfam Description', max_length=100)
    domainfamily = models.CharField('', max_length=25)  #TODO: what is this field? check database contents
    
class BindingSite(models.Model):
    protein_id = models.ForeignKey('Protein')
    domain_id = models.ForeignKey('Domain')

class Complex(models.Model):
    protein_id = models.ForeignKey('Protein')
    copy_nb = models.IntegerField('Number of copies')

class Ppi(models.Model):
    complex_id_1 = models.ForeignKey(Complex, related_name='cplx_id_1')
    complex_id_2 = models.ForeignKey(Complex, related_name='cplx_id_2')
    binding_site_id_1 = models.ForeignKey(BindingSite, related_name='binding_site_id_1')
    binding_site_id_2 = models.ForeignKey(BindingSite, related_name='binding_site_id_2')

class PpiArchitecture(models.Model):
    ppi_id = models.ForeignKey(Ppi)
    pdb_id = models.CharField('PDB ID', max_length=4)

"""





class Actionevidencetest(models.Model):
    idcmpdaction = models.ForeignKey('Cmpdaction', models.DO_NOTHING, db_column='IDCmpdAction')  # Field name made lowercase.
    idtestactivity = models.ForeignKey('Testactivitydescription', models.DO_NOTHING, db_column='IDTestActivity')  # Field name made lowercase.
    nbcopycompound = models.IntegerField(db_column='NbCopyCompound', blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'actionEvidenceTest'
        unique_together = (('idcmpdaction', 'idtestactivity'),)


class Actionevidencexray(models.Model):
    idcmpdaction = models.ForeignKey('Cmpdaction', models.DO_NOTHING, db_column='IDCmpdAction')  # Field name made lowercase.
    codepdb = models.CharField(db_column='CodePDB', max_length=4)  # Field name made lowercase.
    nbcopycompound = models.IntegerField(db_column='NbCopyCompound')  # Field name made lowercase.
    idbindingsite = models.ForeignKey('Bindingsite', models.DO_NOTHING, db_column='IDBindingSite')  # Field name made lowercase.
    idbiblio = models.ForeignKey('Biblio', models.DO_NOTHING, db_column='IDBiblio', blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'actionEvidenceXRay'
        unique_together = (('idcmpdaction', 'codepdb'),)


class Biblio(models.Model):
    idbiblio = models.AutoField(db_column='IDBiblio', primary_key=True)  # Field name made lowercase.
    source = models.CharField(db_column='Source', max_length=7)  # Field name made lowercase.
    idsource = models.CharField(db_column='IDSource', max_length=25)  # Field name made lowercase.
    title = models.CharField(db_column='Title', max_length=300)  # Field name made lowercase.
    listauthor = models.CharField(db_column='ListAuthor', max_length=500)  # Field name made lowercase.
    yearbiblio = models.IntegerField(db_column='YearBiblio')  # Field name made lowercase.
    cytotox = models.CharField(db_column='Cytotox', max_length=1)  # Field name made lowercase.
    insilico = models.CharField(db_column='InSilico', max_length=1)  # Field name made lowercase.
    invitro = models.CharField(db_column='InVitro', max_length=1)  # Field name made lowercase.
    invivo = models.CharField(db_column='InVivo', max_length=1)  # Field name made lowercase.
    incellulo = models.CharField(db_column='InCellulo', max_length=1)  # Field name made lowercase.
    pharmacokinetic = models.CharField(db_column='Pharmacokinetic', max_length=1)  # Field name made lowercase.
    xray = models.CharField(db_column='XRay', max_length=1)  # Field name made lowercase.
    journalname = models.CharField(db_column='JournalName', max_length=50, blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'biblio'
        unique_together = (('source', 'idsource'),)


class Bindingsite(models.Model):
    idbindingsite = models.IntegerField(db_column='IDBindingSite')  # Field name made lowercase.
    idprotein = models.ForeignKey('Protein', models.DO_NOTHING, db_column='IDProtein')  # Field name made lowercase.
    iddomain = models.ForeignKey('Domain', models.DO_NOTHING, db_column='IDDomain')  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'bindingSite'
        unique_together = (('idbindingsite', 'idprotein', 'iddomain'),)


class Bindingsiteevidence(models.Model):
    idppi = models.ForeignKey('Ppi', models.DO_NOTHING, db_column='IDPPI')  # Field name made lowercase.
    idbindingsite = models.ForeignKey(Bindingsite, models.DO_NOTHING, db_column='IDBindingSite')  # Field name made lowercase.
    codepdb = models.CharField(db_column='CodePDB', max_length=4)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'bindingSiteEvidence'
        unique_together = (('idppi', 'idbindingsite'),)


class Cmpdaction(models.Model):
    idcmpdaction = models.AutoField(db_column='IDCmpdAction', primary_key=True)  # Field name made lowercase.
    idcomplexebound = models.ForeignKey('Complexe', models.DO_NOTHING, db_column='IDComplexeBound')  # Field name made lowercase.
    idcompound = models.ForeignKey('Compound', models.DO_NOTHING, db_column='IDCompound')  # Field name made lowercase.
    activationmode = models.CharField(db_column='ActivationMode', max_length=11)  # Field name made lowercase.
    modulationtype = models.CharField(db_column='ModulationType', max_length=10)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'cmpdAction'


class Cmpdactiveresult(models.Model):
    idcompound = models.ForeignKey('Compound', models.DO_NOTHING, db_column='IDCompound')  # Field name made lowercase.
    idtestactivity = models.ForeignKey('Testactivitydescription', models.DO_NOTHING, db_column='IDTestActivity')  # Field name made lowercase.
    activitytype = models.CharField(db_column='ActivityType', max_length=5)  # Field name made lowercase.
    activity = models.DecimalField(db_column='Activity', max_digits=4, decimal_places=2)  # Field name made lowercase.
    pourcentinhib = models.IntegerField(db_column='PourcentInhib', blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'cmpdActiveResult'
        unique_together = (('idcompound', 'idtestactivity', 'activitytype'),)


class Cmpdcytotoxresult(models.Model):
    idcompound = models.ForeignKey('Compound', models.DO_NOTHING, db_column='IDCompound')  # Field name made lowercase.
    idtestcytotox = models.ForeignKey('Testcytotoxdescription', models.DO_NOTHING, db_column='IDTestCytotox')  # Field name made lowercase.
    toxicity = models.CharField(db_column='Toxicity', max_length=1)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'cmpdCytotoxResult'
        unique_together = (('idcompound', 'idtestcytotox'),)


class Cmpdinactiveresult(models.Model):
    idtestactivity = models.ForeignKey('Testactivitydescription', models.DO_NOTHING, db_column='IDTestActivity')  # Field name made lowercase.
    idcompound = models.ForeignKey('Compound', models.DO_NOTHING, db_column='IDCompound')  # Field name made lowercase.
    pourcentinhib = models.IntegerField(db_column='PourcentInhib', blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'cmpdInactiveResult'
        unique_together = (('idtestactivity', 'idcompound'),)


class Cmpdpkresult(models.Model):
    idcompound = models.ForeignKey('Compound', models.DO_NOTHING, db_column='IDCompound')  # Field name made lowercase.
    idtestpk = models.ForeignKey('Testpkdescription', models.DO_NOTHING, db_column='IDTestPK')  # Field name made lowercase.
    tolerated = models.CharField(db_column='Tolerated', max_length=1)  # Field name made lowercase.
    auc = models.IntegerField(db_column='AUC', blank=True, null=True)  # Field name made lowercase.
    clearance = models.DecimalField(db_column='Clearance', max_digits=7, decimal_places=3, blank=True, null=True)  # Field name made lowercase.
    cmax = models.DecimalField(db_column='Cmax', max_digits=7, decimal_places=3, blank=True, null=True)  # Field name made lowercase.
    oralbioavailability = models.IntegerField(db_column='OralBioavailability', blank=True, null=True)  # Field name made lowercase.
    tdemi = models.IntegerField(db_column='Tdemi', blank=True, null=True)  # Field name made lowercase.
    tmax = models.IntegerField(db_column='Tmax', blank=True, null=True)  # Field name made lowercase.
    voldistribution = models.DecimalField(db_column='VolDistribution', max_digits=5, decimal_places=2, blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'cmpdPKResult'
        unique_together = (('idcompound', 'idtestpk'),)


class Complexe(models.Model):
    idcomplexe = models.AutoField(db_column='IDComplexe', primary_key=True)  # Field name made lowercase.
    idprotein = models.ForeignKey('Protein', models.DO_NOTHING, db_column='IDProtein')  # Field name made lowercase.
    nbcopy = models.IntegerField(db_column='NbCopy')  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'complexe'


class Compound(models.Model):
    idcompound = models.AutoField(db_column='IDCompound', primary_key=True)  # Field name made lowercase.
    canonicalsmile = models.CharField(db_column='CanonicalSmile', unique=True, max_length=250)  # Field name made lowercase.
    physchemfilter = models.CharField(db_column='PhysChemFilter', max_length=2)  # Field name made lowercase.
    htsfilter = models.CharField(db_column='HTSFilter', max_length=1)  # Field name made lowercase.
    ismacrocycle = models.CharField(db_column='IsMacrocycle', max_length=1)  # Field name made lowercase.
    aromaticratio = models.DecimalField(db_column='AromaticRatio', max_digits=3, decimal_places=2)  # Field name made lowercase.
    balabanindex = models.DecimalField(db_column='BalabanIndex', max_digits=3, decimal_places=2)  # Field name made lowercase.
    csp3ratio = models.DecimalField(db_column='Csp3Ratio', max_digits=3, decimal_places=2)  # Field name made lowercase.
    dhpetitjean = models.DecimalField(db_column='DhPetitjean', max_digits=4, decimal_places=2)  # Field name made lowercase.
    diamgraphnonhpetitjean = models.IntegerField(db_column='DiamGraphNonHPetitjean')  # Field name made lowercase.
    gcmolarrefractivity = models.DecimalField(db_column='GCMolarRefractivity', max_digits=5, decimal_places=2)  # Field name made lowercase.
    gpetitjean = models.DecimalField(db_column='GPetitjean', max_digits=3, decimal_places=2)  # Field name made lowercase.
    igpetitjean = models.DecimalField(db_column='IgPetitjean', max_digits=3, decimal_places=2)  # Field name made lowercase.
    logd = models.DecimalField(db_column='LogD', max_digits=4, decimal_places=2)  # Field name made lowercase.
    alogp = models.DecimalField(db_column='ALogP', max_digits=4, decimal_places=2)  # Field name made lowercase.
    meanatomvolvdw = models.DecimalField(db_column='MeanAtomVolVdW', max_digits=4, decimal_places=2)  # Field name made lowercase.
    molecularweight = models.DecimalField(db_column='MolecularWeight', max_digits=6, decimal_places=2)  # Field name made lowercase.
    nbacceptorh = models.IntegerField(db_column='NbAcceptorH')  # Field name made lowercase.
    nbaliphaticsamines = models.IntegerField(db_column='NbAliphaticsAmines')  # Field name made lowercase.
    nbaromaticbonds = models.IntegerField(db_column='NbAromaticBonds')  # Field name made lowercase.
    nbaromaticsether = models.IntegerField(db_column='NbAromaticsEther')  # Field name made lowercase.
    nbaromaticssssr = models.IntegerField(db_column='NbAromaticsSSSR')  # Field name made lowercase.
    nbatom = models.IntegerField(db_column='NbAtom')  # Field name made lowercase.
    nbatomnonh = models.IntegerField(db_column='NbAtomNonH')  # Field name made lowercase.
    nbbenzlikerings = models.IntegerField(db_column='NbBenzLikeRings')  # Field name made lowercase.
    nbbonds = models.IntegerField(db_column='NbBonds')  # Field name made lowercase.
    nbbondsnonh = models.IntegerField(db_column='NbBondsNonH')  # Field name made lowercase.
    nbbr = models.IntegerField(db_column='NbBr')  # Field name made lowercase.
    nbc = models.IntegerField(db_column='NbC')  # Field name made lowercase.
    nbchiralcenters = models.IntegerField(db_column='NbChiralCenters')  # Field name made lowercase.
    nbcircuits = models.IntegerField(db_column='NbCircuits')  # Field name made lowercase.
    nbcl = models.IntegerField(db_column='NbCl')  # Field name made lowercase.
    nbcsp2 = models.IntegerField(db_column='NbCsp2')  # Field name made lowercase.
    nbcsp3 = models.IntegerField(db_column='NbCsp3')  # Field name made lowercase.
    nbdonorh = models.IntegerField(db_column='NbDonorH')  # Field name made lowercase.
    nbdoublebonds = models.IntegerField(db_column='NbDoubleBonds')  # Field name made lowercase.
    nbf = models.IntegerField(db_column='NbF')  # Field name made lowercase.
    nbi = models.IntegerField(db_column='NbI')  # Field name made lowercase.
    nbmultbonds = models.IntegerField(db_column='NbMultBonds')  # Field name made lowercase.
    nbn = models.IntegerField(db_column='NbN')  # Field name made lowercase.
    nbo = models.IntegerField(db_column='NbO')  # Field name made lowercase.
    nbrings = models.IntegerField(db_column='NbRings')  # Field name made lowercase.
    nbrotatablebonds = models.IntegerField(db_column='NbRotatableBonds')  # Field name made lowercase.
    radiusgraphnonhpetitjean = models.IntegerField(db_column='RadiusGraphNonHPetitjean')  # Field name made lowercase.
    randicindex = models.DecimalField(db_column='RandicIndex', max_digits=4, decimal_places=2)  # Field name made lowercase.
    rdf070m = models.DecimalField(db_column='RDF070m', max_digits=5, decimal_places=2)  # Field name made lowercase.
    rotatablebondfraction = models.DecimalField(db_column='RotatableBondFraction', max_digits=3, decimal_places=2)  # Field name made lowercase.
    sumatompolar = models.DecimalField(db_column='SumAtomPolar', max_digits=5, decimal_places=2)  # Field name made lowercase.
    sumatomvolvdw = models.DecimalField(db_column='SumAtomVolVdW', max_digits=6, decimal_places=2)  # Field name made lowercase.
    surfacevdwpetitjean = models.DecimalField(db_column='SurfaceVDWPetitjean', max_digits=6, decimal_places=2)  # Field name made lowercase.
    thicknesspetitjean = models.DecimalField(db_column='ThicknessPetitjean', max_digits=4, decimal_places=2)  # Field name made lowercase.
    tpsa = models.DecimalField(db_column='TPSA', max_digits=5, decimal_places=2)  # Field name made lowercase.
    ui = models.DecimalField(db_column='Ui', max_digits=4, decimal_places=2)  # Field name made lowercase.
    volvdwpetitjean = models.DecimalField(db_column='VolVDWPetitjean', max_digits=7, decimal_places=2)  # Field name made lowercase.
    wienerindex = models.IntegerField(db_column='WienerIndex')  # Field name made lowercase.
    cmpdnamesh = models.CharField(db_column='CmpdNameSh', max_length=20, blank=True, null=True)  # Field name made lowercase.
    idpubchem = models.CharField(db_column='IdPubchem', max_length=10, blank=True, null=True)  # Field name made lowercase.
    idchemspider = models.CharField(db_column='IdChemspider', max_length=10, blank=True, null=True)  # Field name made lowercase.
    idchembl = models.CharField(db_column='IDChembl', max_length=30, blank=True, null=True)  # Field name made lowercase.
    cmpdiupacname = models.CharField(db_column='CmpdIUPACName', max_length=255, blank=True, null=True)  # Field name made lowercase.
    idmddrcompound = models.ForeignKey('Mddrcompound', models.DO_NOTHING, db_column='IDMDDRCompound', blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'compound'


class Disease(models.Model):
    idppi = models.ForeignKey('Ppi', models.DO_NOTHING, db_column='IDPPI')  # Field name made lowercase.
    disease = models.CharField(db_column='Disease', max_length=30)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'disease'
        unique_together = (('idppi', 'disease'),)


class DjangoMigrations(models.Model):
    app = models.CharField(max_length=255)
    name = models.CharField(max_length=255)
    applied = models.DateTimeField()

    class Meta:
#        managed = False
        db_table = 'django_migrations'


class Domain(models.Model):
    iddomain = models.AutoField(db_column='IDDomain', primary_key=True)  # Field name made lowercase.
    pfamid = models.CharField(db_column='PfamID', max_length=20)  # Field name made lowercase.
    pfamnumaccession = models.CharField(db_column='PfamNumAccession', unique=True, max_length=10)  # Field name made lowercase.
    domaindescription = models.CharField(db_column='DomainDescription', max_length=100)  # Field name made lowercase.
    domainfamily = models.CharField(db_column='DomainFamily', max_length=25)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'domain'


class Mddrcmpdactclass(models.Model):
    idmddrcompound = models.ForeignKey('Mddrcompound', models.DO_NOTHING, db_column='IDMDDRCompound')  # Field name made lowercase.
    activityclass = models.CharField(db_column='ActivityClass', max_length=60)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'mDDRCmpdActClass'
        unique_together = (('idmddrcompound', 'activityclass'),)


class Mddrcompound(models.Model):
    idmddrcompound = models.IntegerField(db_column='IDMDDRCompound')  # Field name made lowercase.
    mddrcmpdname = models.CharField(db_column='MDDRCmpdName', max_length=40)  # Field name made lowercase.
    phasedvpmt = models.CharField(db_column='PhaseDvpmt', max_length=20)  # Field name made lowercase.
    canonicalsmile = models.CharField(db_column='CanonicalSmile', max_length=500, blank=True, null=True)  # Field name made lowercase.
    versionmddr = models.CharField(db_column='VersionMDDR', max_length=7)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'mDDRCompound'
        unique_together = (('idmddrcompound', 'mddrcmpdname', 'phasedvpmt'),)


class Mddrsimilarity(models.Model):
    idcompound = models.ForeignKey(Compound, models.DO_NOTHING, db_column='IDCompound')  # Field name made lowercase.
    idmddrcompound = models.ForeignKey(Mddrcompound, models.DO_NOTHING, db_column='IDMDDRCompound')  # Field name made lowercase.
    versionmddr = models.CharField(db_column='VersionMDDR', max_length=7)  # Field name made lowercase.
    tanimoto = models.DecimalField(db_column='Tanimoto', max_digits=6, decimal_places=5)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'mDDRSimilarity'
        unique_together = (('idcompound', 'idmddrcompound', 'versionmddr'),)


class Ppi(models.Model):
    idppi = models.AutoField(db_column='IDPPI', primary_key=True)  # Field name made lowercase.
    idcomplexe1 = models.ForeignKey(Complexe, models.DO_NOTHING, db_column='IDComplexe1', related_name='cplx_id_1')  # Field name made lowercase.
    idcomplexe2 = models.ForeignKey(Complexe, models.DO_NOTHING, db_column='IDComplexe2', related_name='cplx_id_2')  # Field name made lowercase.
    idbindingsite1 = models.ForeignKey(Bindingsite, models.DO_NOTHING, db_column='IDBindingSite1', related_name='bs_id_1') # Field name made lowercase.
    idbindingsite2 = models.ForeignKey(Bindingsite, models.DO_NOTHING, db_column='IDBindingSite2', related_name='bs_id_2')  # Field name made lowercase.
    family = models.CharField(db_column='Family', max_length=25)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'ppi'
        unique_together = (('idcomplexe1', 'idcomplexe2', 'idbindingsite1', 'idbindingsite2'),)


class Protein(models.Model):
    idprotein = models.AutoField(db_column='IDProtein', primary_key=True)  # Field name made lowercase.
    numuniprot = models.CharField(db_column='NumUniprot', unique=True, max_length=10)  # Field name made lowercase.
    protnamelg = models.CharField(db_column='ProtNameLg', max_length=75)  # Field name made lowercase.
    protnamesh = models.CharField(db_column='ProtNameSh', max_length=50)  # Field name made lowercase.
    protalias = models.CharField(db_column='ProtAlias', unique=True, max_length=30)  # Field name made lowercase.
    protnamesp = models.CharField(db_column='ProtNameSp', max_length=30)  # Field name made lowercase.
    organism = models.CharField(db_column='Organism', max_length=80)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'protein'


class Refcmpdbiblio(models.Model):
    idcompound = models.ForeignKey(Compound, models.DO_NOTHING, db_column='IDCompound')  # Field name made lowercase.
    idbiblio = models.ForeignKey(Biblio, models.DO_NOTHING, db_column='IDBiblio')  # Field name made lowercase.
    cmpdnameinbiblio = models.CharField(db_column='CmpdNameInBiblio', max_length=20, blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'refCmpdBiblio'
        unique_together = (('idcompound', 'idbiblio'),)


class Refproteinfonction(models.Model):
    idprotein = models.ForeignKey(Protein, models.DO_NOTHING, db_column='IDProtein')  # Field name made lowercase.
    protfonctionsp = models.CharField(db_column='ProtFonctionSP', max_length=200)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'refProteinFonction'
        unique_together = (('protfonctionsp', 'idprotein'),)


class Testactivitydescription(models.Model):
    idtestactivity = models.AutoField(db_column='IDTestActivity', primary_key=True)  # Field name made lowercase.
    idcomplexebound = models.ForeignKey(Complexe, models.DO_NOTHING, db_column='IDComplexeBound')  # Field name made lowercase.
    idbiblio = models.ForeignKey(Biblio, models.DO_NOTHING, db_column='IDBiblio')  # Field name made lowercase.
    idppi = models.ForeignKey(Ppi, models.DO_NOTHING, db_column='IDPPI', blank=True, null=True)  # Field name made lowercase.
    testnameactivity = models.CharField(db_column='TestNameActivity', max_length=40)  # Field name made lowercase.
    isprimary = models.CharField(db_column='IsPrimary', max_length=1)  # Field name made lowercase.
    protboundconstruct = models.CharField(db_column='ProtBoundConstruct', max_length=11)  # Field name made lowercase.
    testtype = models.CharField(db_column='TestType', max_length=5)  # Field name made lowercase.
    testmodulationtype = models.CharField(db_column='TestModulationType', max_length=13)  # Field name made lowercase.
    nbactivescmpdstot = models.IntegerField(db_column='NbActivesCmpdsTot')  # Field name made lowercase.
    conccmpds = models.DecimalField(db_column='ConcCmpds', max_digits=7, decimal_places=3, blank=True, null=True)  # Field name made lowercase.
    protocol = models.TextField(db_column='Protocol', blank=True, null=True)  # Field name made lowercase.
    concproteinbound = models.DecimalField(db_column='ConcProteinBound', max_digits=7, decimal_places=3, blank=True, null=True)  # Field name made lowercase.
    concprotein2 = models.DecimalField(db_column='ConcProtein2', max_digits=7, decimal_places=3, blank=True, null=True)  # Field name made lowercase.
    controlepos = models.CharField(db_column='ControlePos', max_length=50, blank=True, null=True)  # Field name made lowercase.
    controleneg = models.CharField(db_column='ControleNeg', max_length=50, blank=True, null=True)  # Field name made lowercase.
    cellline = models.CharField(db_column='CellLine', max_length=50, blank=True, null=True)  # Field name made lowercase.
    pepseq = models.CharField(db_column='PepSeq', max_length=100, blank=True, null=True)  # Field name made lowercase.
    marker = models.CharField(db_column='Marker', max_length=35, blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'testActivityDescription'


class Testcytotoxdescription(models.Model):
    idtestcytotox = models.AutoField(db_column='IDTestCytotox', primary_key=True)  # Field name made lowercase.
    idbiblio = models.ForeignKey(Biblio, models.DO_NOTHING, db_column='IDBiblio')  # Field name made lowercase.
    testnamecytotox = models.CharField(db_column='TestNameCytotox', max_length=40)  # Field name made lowercase.
    cellline = models.CharField(db_column='CellLine', max_length=50)  # Field name made lowercase.
    conccmpd = models.DecimalField(db_column='ConcCmpd', max_digits=7, decimal_places=3, blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'testCytotoxDescription'


class Testpkdescription(models.Model):
    idtestpk = models.AutoField(db_column='IDTestPK', primary_key=True)  # Field name made lowercase.
    idbiblio = models.ForeignKey(Biblio, models.DO_NOTHING, db_column='IDBiblio')  # Field name made lowercase.
    testnamepk = models.CharField(db_column='TestNamePK', max_length=40)  # Field name made lowercase.
    animal = models.CharField(db_column='Animal', max_length=100)  # Field name made lowercase.
    administrationmode = models.CharField(db_column='AdministrationMode', max_length=2, blank=True, null=True)  # Field name made lowercase.
    concentration = models.DecimalField(db_column='Concentration', max_digits=7, decimal_places=3, blank=True, null=True)  # Field name made lowercase.
    dose = models.DecimalField(db_column='Dose', max_digits=7, decimal_places=2, blank=True, null=True)  # Field name made lowercase.
    doseinterval = models.IntegerField(db_column='DoseInterval', blank=True, null=True)  # Field name made lowercase.

    class Meta:
#        managed = False
        db_table = 'testPKDescription'
"""
